<?php

declare(strict_types=1);

namespace SuperRhino\Utils\MQClient;

use SuperRhino\Utils\Facade;


class MQClientAdapter implements MQClientAdapterInterface {
    /**
     * @var MQClient
     */
    protected $client;
    
    public function __construct() {
        $mqConfig = Facade::getContainer()->get(MQConfigInterface::class);
        $this->client = new MQClient(
            $mqConfig->getEndPoint(),
            $mqConfig->getAccessId(),
            $mqConfig->getAccessKey(),
            $mqConfig->getInstanceId()
        );
    }

    public function produce(string $topic, string $messageBody, array $config = []): string {
        return $this->client->produce($topic, $messageBody, $config);
    }

    public function consume(string $topic, string $groupId, int $numOfMessages, int $waitSeconds = 3): array {
        return $this->client->consume($topic, $groupId, $numOfMessages, $waitSeconds);
    }

    public function ack(string $topic, string $groupId, array $receiptHandles): bool {
        return $this->client->ack($topic, $groupId, $receiptHandles);
    }
    
    public function ackMessages(string $topic, string $groupId, array $messages): bool {
        return $this->client->ackMessages($topic, $groupId, $messages);
    }

}
